<?php
include_once 'Lib/Util.inc';
include_once 'models/TodoModel.inc';

function get_detail($params) {
    ensureLoggedIn();
    $id = safeParam($params, 0, false);
    if ($id === false) {
        die('No todo id specified');
    }

    $todo = findToDoById($id);
    if (!$todo) {
        die("No todo with id $id found.");
    }
    renderTemplate(
        'views/todo_detail.inc',
        array(
            'title' => 'Viewing To Do',
            'todo' => $todo
        )
    );
}

function get_list($params) {
    $todos = findAllCurrentToDos();
    $dones = findAllDoneToDos();
    renderTemplate(
        'views/index.inc',
        array(
            'title' => 'To Do List',
            'todos' => $todos,
            'dones' => $dones
        )
    );
}

function get_edit($params) {
    ensureLoggedIn();
    $id = safeParam($params, 0, false);
    if (!$id) {
        die('No todo specified');
    }
    $todo = findToDoById($id);
    if (!$todo) {
        die('No todo found.');
    }
    renderTemplate(
        'views/todo_edit.inc',
        array(
            'title' => 'Editing To Do',
            'todo' => $todo
        )
    );
}

function post_add($params) {
    ensureLoggedIn();
    if (!isset($_POST['description'])) {
        die('no description given');
    }
    $description = htmlentities($_POST['description']);
    addToDo($description);
    redirectRelative('index');
}

function validate_present($elements) {
    $errors = '';
    foreach ($elements as $element) {
        if (!isset($_POST[$element])) {
            $errors .= "Missing $element\n";
        }
    }
    return $errors;
}

function post_update($params) {
    ensureLoggedIn();
    $errors = validate_present(array('id', 'description', 'done'));
    if ($errors) {
        die($errors);
    }
    $id = $_POST['id'];
    $description = $_POST['description'];
    $done = $_POST['done'];
    updateToDo($id, $description, $done);
    redirectRelative("todo/detail/$id");
}

function get_delete($params) {
    ensureLoggedIn();
    $id = safeParam($params, 0, false);
    if (!$id) {
        die('No todo specified');
    }
    $todo = findToDoById($id);
    if (!$todo) {
        die('No todo found.');
    }
    deleteToDo($id);
    redirectRelative('index');
}
